@@ -55,11 +55,7 @@ func (filter *KubernetesContainerFilter) GetContainerList() (containersInfo []*m
 
 	for _, pod := range pods.Items {
 		for _, container := range pod.Spec.Containers {
-			for _, env := range container.Env {
-				if env.Name == MachineNameEnvVar {
-					containersInfo = append(containersInfo, &model.ContainerInfo{ContainerName: container.Name, PodName: pod.Name})
-				}
-			}
+			containersInfo = append(containersInfo, &model.ContainerInfo{ContainerName: container.Name, PodName: pod.Name})
 		}
 	}
 
@@ -121,6 +117,10 @@ func findContainerName(pod v1.Pod, machineName string) string {
 				return container.Name
 			}
 		}
+		// ^ Che specific logic failed, try devworkspace one
+		if container.Name == machineName {
+			return container.Name
+		}
 	}
 	return ""
 }
